Package: microplot
Type: Package
Title: Microplots (Sparklines) in 'LaTeX', 'Word', 'HTML', 'Excel'
Version: 1.0-47
Date: 2025-8-21
Authors@R: c(person(given = c("Richard", "M."),
                    family = "Heiberger",
                    role = c("aut", "cre"),
                    email = "rmh@temple.edu",
                    comment = c(ORCID = "0000-0001-9047-6931")),
             person(given = c("Karen"),
                    family = "Byron",
                    role = "ctb"),
             person(given = "Nooreen",
                    family = "Dabbish",
                    role = "ctb"))
Author: Richard M. Heiberger [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9047-6931>),
  Karen Byron [ctb],
  Nooreen Dabbish [ctb]
Maintainer: Richard M. Heiberger <rmh@temple.edu>
Description: The microplot function writes a set of R graphics files to be used as
  microplots (sparklines) in tables in either 'LaTeX', 'HTML', 'Word',
  or 'Excel' files.  For 'LaTeX', we provide methods for the
  Hmisc::latex() generic function to construct 'latex' tabular
  environments which include the graphs.  These can be used directly
  with the operating system 'pdflatex' or 'latex' command, or by using
  one of 'Sweave', 'knitr', 'rmarkdown', or 'Emacs org-mode' as an
  intermediary.  For 'MS Word', the msWord() function uses the
  'flextable' package to construct 'Word' tables which include the
  graphs.  There are several distinct approaches for constructing HTML
  files.  The simplest is to use the msWord() function with argument
  filetype="html".  Alternatively, use either 'Emacs org-mode' or the
  htmlTable::htmlTable() function to construct an 'HTML' file
  containing tables which include the graphs.  See the documentation
  for our as.htmlimg() function.  For 'Excel' use on 'Windows', the
  file examples/irisExcel.xls includes 'VBA' code which brings the
  individual panels into individual cells in the spreadsheet.
  Examples in the examples and demo subdirectories are shown with
  'lattice' graphics, 'ggplot2' graphics, and 'base' graphics.
  Examples for 'LaTeX' include 'Sweave' (both 'LaTeX'-style and
  'Noweb'-style), 'knitr', 'emacs org-mode', and 'rmarkdown' input
  files and their 'pdf' output files.  Examples for 'HTML' include
  'org-mode' and 'Rmd' input files and their webarchive 'HTML' output
  files.  In addition, the as.orgtable() function can display a
  data.frame in an 'org-mode' document.  The examples for 'MS Word'
  (with either filetype="docx" or filetype="html") work with all
  operating systems.  The package does not require the installation of
  'LaTeX' or 'MS Word' to be able to write '.tex' or '.docx' files.
Imports: Hmisc (>= 4.1-1), HH, lattice, grid, flextable (>= 0.5-11),
        officer, ggplot2, htmltools, cowplot
Suggests: reshape2, latticeExtra, xtable, markdown, rmarkdown, knitr,
        htmlTable
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2025-07-22 23:19:11 UTC; rmh
Repository: CRAN
Date/Publication: 2025-07-25 03:10:08 UTC
Built: R 4.6.0; ; 2026-04-25 13:46:32 UTC; unix
