## exportPattern("^[[:alpha:]]+")
export(
  msWord,
  microplot,
  layoutHeightsCollapse,
  layoutWidthsCollapse,
  layoutCollapse,
  as.htmlimg,
  as.includegraphics,
  as.orgfile,
  as.orgtable,
  theme_collapse,
  microplotAttrDisplay,
  latexCheckOptions,
  latexSetOptions,
  latex,
  dvi,
  optionsCmds,
  plot_grid,
  get_legend,
  show.latexConsole,
  formatDF,
  graphicsList,
  dir.verify
)
importFrom(Hmisc, latex, dvi, first.word, latexCheckOptions, optionsCmds, sys, format.df)
importFrom(stats, update, as.formula)
importFrom(grDevices, dev.off, pdf, png, postscript)
if (version$os == "mingw32") importFrom(grDevices, win.metafile)
importFrom(grid, grid.newpage)
importFrom(lattice, draw.key)
importFrom(HH, AEdotplot) ## as.vector.trellis
## (something must be imported from HH to get the NAMESPACE loaded and
## therefore provide access to the trellis method for as.vector)
## importFrom(ReporteRs, FlexTable, addFlexTable, addHeaderRow, addParagraph,
##   borderNone, borderProperties, cellProperties,  docx, parProperties, pot_img,
##   setFlexTableBorders, setFlexTableWidths, textProperties, writeDoc, addSection)
importFrom(ggplot2, element_blank, element_line, element_text, xlab, ylab,
           aes, geom_line, ggplot, scale_colour_manual,
           scale_x_continuous, scale_y_continuous, theme, theme_minimal)
importFrom(htmltools, save_html, browsable, HTML)
importFrom(cowplot, plot_grid, get_legend, plot_to_gtable)
importFrom(flextable, add_footer, add_header, align, body_add_flextable,
           bold, border_inner_h, border_inner_v, compose, flextable, height,
           hline, merge_at, merge_h, set_header_labels, width,
           as_image, as_paragraph)
importFrom(officer, read_docx, fp_border,
           body_add_par, body_end_section_landscape, body_end_section_portrait)

## register all the methods for generics elsewhere in case namespace is
## loaded but not currently attached.
S3method(microplot, trellis)
S3method(microplot, ggplot)
S3method(microplot, graphicsList)
S3method(microplot, AEdotplot)
S3method(latex, trellis)
S3method(latex, ggplot)
S3method(latex, graphicsList)
S3method(latex, graphicsClass)
S3method(latex, microplotMatrix)
S3method(latex, includegraphicsMatrix)
S3method(latex, AEdotplot)
S3method(dvi, latexConsole)
S3method(print, latexConsole)
S3method(print, OSfilename)
S3method(print, dvilC)
S3method(msWord, trellis)
S3method(msWord, ggplot)
S3method(msWord, graphicsList)
S3method(msWord, microplotMatrix)
S3method(msWord, graphicsClass)
S3method(msWord, AEdotplot)
S3method(as.includegraphics, default)
S3method(as.includegraphics, trellis)
S3method(as.includegraphics, ggplot)
S3method(as.includegraphics, graphicsList)
S3method(as.includegraphics, microplotMatrix)
S3method(as.includegraphics, includegraphicsMatrix)
S3method("[", microplotMatrix)
S3method("[", includegraphicsMatrix)
