## files in microplot/examples directory showing microplot with:
## Sweave, knitr, markdown, RMarkdown, noweb, org mode, Word, Excel

## to run these files, first copy them to a directory where you have write privilege
list.files(system.file(package="microplot", "examples"), full.names=TRUE)
